// z-stack
@z-present: 999;
@z-presented: 1000;

@z-speaker: 9001;
@z-help: 9001;

@z-app-bar: 9002;
@z-editor: 9002;
@z-regiontree: 9002;
@z-sorter: 9002;
@z-layouts: 9002;
@z-link-overlay: 9002;

@z-theme-mgr: 9003;
@z-theme-editor: 9002;

@z-tour: 9999;

// colors
@ui-bg: #222;
@ui-bg-alpha: rgba(50, 50, 50, 0.95);
@jpy-brand: #f37626;
@active: #337ab7;
@part-source-color: #303F9F;
@part-outputs-color: #D84315;
@part-widgets-color: average(@part-source-color, @part-outputs-color);
@part-whole-color: @jpy-brand;


// misc
@btn-titled-height: 64px;

// app
@app-bar-width: 78px;

// theme
@theme-card-height: @sorter-slide-height;
@theme-mgr-height: @theme-card-height + 48;
@theme-swatch-size: 24px;
@theme-card-swatch-size: 15px;

// sorter
@sorter-slide-width: 160px;
@sorter-slide-height: 90px;
@sorter-height: @sorter-slide-height + 100;

// editor
@editor-sidebar-width: 320px;

// pretties
@z-shadow: 0px 0px 12px 1px rgba(87, 87, 87, 0.2);

// tour
@tour-padding: 24px;

// transitions
@tx-dur: 0.2s;
@tx-fn: ease;
