export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
export ARCH="32"
export PREFIX="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
export BUILD_PREFIX="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-32"
export SRC_DIR="/opt/conda/conda-bld/nbpresent_1505142139031/work"
export ROOT="/opt/conda"
export CONDA_PY="36"
export PY3K="1"
export PY_VER="3.6"
export STDLIB_DIR="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/python3.6"
export SP_DIR="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/python3.6/site-packages"
export PYTHON="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python"
export NPY_VER="1.8"
export CONDA_NPY="18"
export PERL_VER="5.26"
export CONDA_PERL="5.26"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3"
export CONDA_R="3"
export PKG_NAME="nbpresent"
export PKG_VERSION="3.0.2"
export PKG_BUILDNUM="1"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/home/rdonnelly/conda/aggregate/nbpresent-feedstock/recipe"
export CPU_COUNT="20"
export LANG="en_US.UTF-8"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".so"
export PATH="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla:/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin:/opt/conda/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
export HOME="/home/rdonnelly"
export PKG_CONFIG_PATH="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib"
export BUILD="i686-conda_cos6-linux-gnu"
export r_base="3"
export cpu_optimization_target="nocona"
export target_platform="linux-32"
export blas_impl="mkl"
export boost="1.64"
export bzip2="1.0"
export VERBOSE_AT="V=1"
export VERBOSE_CM="VERBOSE=1"
export dbus="1"
export expat="2.2"
export fontconfig="2.12"
export freetype="2.8"
export gstreamer="1.12"
export gst_plugins_base="1.12"
export geos="3.6.0"
export giflib="5.1"
export glib="2.53"
export harfbuzz="1.5"
export hdf4="4.2"
export hdf5="1.10"
export icu="58"
export jpeg="9"
export libdap4="3.19"
export libkml="1.3"
export libnetcdf="4.4"
export libpng="1.6"
export libtiff="4.0"
export libxml2="2.9"
export macos_min_version="10.9"
export macos_machine="x86_64-apple-darwin13.4.0"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export mkl="2018"
export openblas="0.2.19"
export proj4="4"
export scipy="0.19"
export sqlite="3"
export vc="14"
export zlib="1.2"
export xz="5"
export zip_keys="[['python', 'ipython']]"
export pin_run_as_build="{'python': {'min_pin': 'x.x', 'max_pin': 'x.x'}}"
export ipython="6.1"
export CONDA_BUILD_STATE="BUILD"
source "/opt/conda/bin/activate" "/opt/conda/conda-bld/nbpresent_1505142139031/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
npm install
npm run build:release
rm -rf node_modules
"${PYTHON}" setup.py install --single-version-externally-managed --record=record.txt
"${PREFIX}/bin/jupyter-nbextension" install nbpresent --py --sys-prefix --overwrite
